@@ -276,7 +276,7 @@ class SimpleObject(CumulocityObject):
         self.c8y.delete(self._build_object_path())
 
 
-class ComplexObject(SimpleObject):
+class ComplexObject(SimpleObject, dict):
     """Abstract base class for all complex cumulocity objects
     (that can have custom fragments)."""
 
@@ -336,7 +336,12 @@ class ComplexObject(SimpleObject):
 
         :param name: Name of the custom fragment
         """
-        return self.__getitem__(name)
+        try:
+            return self.__getitem__(name)
+        except KeyError:
+            raise AttributeError(
+                f"'{type(self).__name__}' object has no attribute '{name}'"
+            ) from None
 
     def _setattr_(self, name, value):
         if name in self.fragments:
@@ -406,6 +411,18 @@ class ComplexObject(SimpleObject):
         result.c8y = self.c8y
         return result
 
+    def items(self):
+        """Returns the objects' fragments as dictionary items."""
+        return self.fragments.items()
+
+    def keys(self):
+        """Returns the objects' fragment names."""
+        return self.fragments.keys()
+
+    def values(self):
+        """Returns the objects' fragment values."""
+        return self.fragments.values()
+
 
 class CumulocityResource:
     """Abstract base class for all Cumulocity API resources."""
@@ -432,7 +449,11 @@ class CumulocityResource:
     @staticmethod
     def _prepare_query_params(type=None, name=None, fragment=None, source=None,  # noqa (type)
                               series=None, owner=None,
-                              before=None, after=None, min_age=None, max_age=None,
+                              device_id=None, agent_id=None, bulk_id=None,
+                              before=None, after=None,
+                              created_before=None, created_after=None,
+                              updated_before=None, updated_after=None,
+                              min_age=None, max_age=None,
                               reverse=None, page_size=None, **kwargs):
         # min_age/max_age should be timedelta objects that can be used for
         # alternative calculation of the before/after parameters
@@ -451,11 +472,20 @@ class CumulocityResource:
         # if so they need to be timezone aware
         before = _DateUtil.ensure_timestring(before)
         after = _DateUtil.ensure_timestring(after)
+        created_before = _DateUtil.ensure_timestring(created_before)
+        created_after = _DateUtil.ensure_timestring(created_after)
+        updated_before = _DateUtil.ensure_timestring(updated_before)
+        updated_after = _DateUtil.ensure_timestring(updated_after)
 
         params = {k: v for k, v in {'type': type, 'name': name, 'owner': owner,
                                     'source': source, 'fragmentType': fragment,
                                     'valueFragmentSeries': series,
-                                    'dateFrom': after, 'dateTo': before, 'revert': str(reverse) if reverse else None,
+                                    'deviceId': device_id, 'agentId': agent_id,
+                                    'bulkOperationId': bulk_id,
+                                    'dateFrom': after, 'dateTo': before,
+                                    'createdFrom': created_after, 'createdTo': created_before,
+                                    'lastUpdatedFrom': updated_after, 'lastUpdatedTo': updated_before,
+                                    'revert': str(reverse) if reverse else None,
                                     'pageSize': page_size}.items() if v}
         params.update({k: v for k, v in kwargs.items() if v is not None})
         return params
